# tinyIOC

A lightweight python library for dependency injection.
It allows service injection using one decorator on top of your function, and service registration in multiple ways:

- programmatically
- through decorators
- declaratively through modules

## Install

Install it from pypi:

```sh
pip install tinyioc
```

## Documentation

Read the docs here: [https://tinyioc.readthedocs.io/en/latest/](https://tinyioc.readthedocs.io/en/latest/)

## License

This library is licensed under MIT license: more info [here](https://github.com/paolo-projects/tinyioc/blob/main/LICENSE)
